@@ -17,7 +17,8 @@ CROP_TYPE = {
     'm_bo': ['模特下身正面', '模特下身侧面', '模特下身背面'],
     'm_f': ['模特全身正面', '模特全身侧面', '模特全身背面'],
     't': ['平铺图背面', '平铺图正面'],
-    'b': ['资质图', '吊牌图', '洗水唛']
+    'b': ['资质图', '吊牌图', '洗水唛'],
+    'g': ['动图'],
 }
 
 
@@ -312,9 +313,9 @@ class Image:
                     if cat == 'tile':
                         return cat_mapping[cat] + cat_mapping[sub_category]
                     return cat_mapping[sub_category]
-                if '细节' not in self.ai_image_classification:
+                if cat == 'detail':
                     # 来个默认细节图
-                    return '衣袖'
+                    return "细节图"
                 # 保持原有识别
                 return self.ai_image_classification
             model, body = cat.split('-')
@@ -522,6 +523,75 @@ class Human:
             mandible_point[2] = 1
         return mandible_point
 
+    def calculate_x_human_center(self, crop_top, crop_bottom):
+
+        """
+        1.优先根据 左臀、右臀、腰、脊柱来计算，
+        2.算不出来则 选择人体衣服外边框
+
+        crop_top : 当前图片裁剪的上点
+        crop_bottom： 当前图片裁剪的下点
+        :return:
+        """
+        confidence = 0.4  # 人体主干关键点 置信度需要大于0.5
+
+        if not self.image_analysis.get('recognition'):  # 新版本ai识别结果不存在
+            return None
+
+        recognition = json.loads(self.image_analysis.get('recognition'))  # 识别结果内不存在人体关键点
+        human_bodies_list = recognition.get('human_bodies')
+        if not human_bodies_list:
+            return None
+
+        all_human_center = []
+
+        for i, human in enumerate(human_bodies_list):
+            human_keypoint_list = human['keypoints']
+            # ['右踝', '右膝', '右臀', '左臀', '左膝', '左踝', '腰', '脊柱', '颈', '头', '右腕', '右肘', '右肩', '左肩', '左肘', '左腕']
+            r_ank, r_kne, r_hip, l_hip, l_kne, l_ank, pel, spi, nec, hea, r_wri, r_elb, r_sho, l_sho, l_elb, l_wri = human_keypoint_list
+
+            # 有效的点
+            valid_point_list = []
+
+            # 不分左右的点 腰 pel、脊柱 spi
+            # 1.置信度够
+            # 2.在裁剪范围内
+            pel_h = pel[1]/self.image_height
+            pel_w = pel[0]/self.image_width
+            if pel[2] >= confidence and crop_top <= pel_h <= crop_bottom:
+                valid_point_list.append(pel_w)
+
+            spi_h = spi[1]/self.image_height
+            spi_w = spi[0]/self.image_width
+            if spi[2] >= confidence and crop_top <= spi_h <= crop_bottom:
+                valid_point_list.append(spi_w)
+
+            # 分左右的点 左臀 l_hip、右臀 r_hip
+            # 1. 左右点置信度都够
+            # 2. 有一个点的 上下在裁剪范围内
+            l_hip_h = l_hip[1]/self.image_height
+            r_hip_h =  r_hip[1]/self.image_height
+            l_hip_w = l_hip[0]/self.image_width
+            r_hip_w = r_hip[0]/self.image_width
+
+
+            if l_hip[2] >= confidence and r_hip[2] >= confidence and \
+                    (crop_top <= l_hip_h <= crop_bottom or crop_top <= r_hip_h <= crop_bottom):
+
+                hip_w = l_hip_w + (r_hip_w - l_hip_w)/2
+
+                valid_point_list.append( hip_w )
+
+            if valid_point_list:
+                current_human_center = sum(valid_point_list) / len(valid_point_list)
+                all_human_center.append(current_human_center)
+
+        if not all_human_center:
+            return None
+
+        return sum(all_human_center) / len(all_human_center)
+
+
     def add_new_crop_point(self, recognition, human_pose):
         """
         把 recognition 内的数据 添加到 旧版的17个人体关键点的数据结构中
