@@ -182,7 +182,7 @@ class ImageCrop:
                 transform_img_height = width_scale * img.height
                 scale_x = scale_y = width_scale
                 x = x1
-                y = top
+                y = y1
                 crop_width = slot_width / scale_x
                 crop_height = ((y2 - y1) * img.height)
                 amend_layout_height = (y2 - y1) * transform_img_height - slot_height
@@ -198,7 +198,7 @@ class ImageCrop:
                 tag_2 = center_ + slot_width / 2
                 if tag_1 >= 0 and tag_2 <= transform_img_width:  # 两边都满足，直接居中裁剪
                     scale_x = scale_y = height_scale
-                    y = top
+                    y = y1
                     x = (center_ - slot_width / 2) / transform_img_width
                     crop_width = slot_width / scale_x
                     crop_height = slot_height / scale_x
@@ -210,7 +210,7 @@ class ImageCrop:
                     transform_img_height = width_scale * img.height
                     scale_x = scale_y = width_scale
                     x = x_center - min_x
-                    y = top
+                    y = y1
                     crop_width = slot_width / scale_x
                     crop_height = ((y2 - y1) * img.height)
                     amend_layout_height = (y2 - y1) * transform_img_height - slot_height
